@@ -79,7 +79,7 @@ def app(static=None):
     """
     if static != None:
         static = Cling(static)
-        app = URLRelay(default=static_app)
+        app = URLRelay(default=static)
     else:
         app = URLRelay()
     return app
